@@ -1,11 +1,11 @@
 import sys
 
-from .qiwi import QiwiWrapper, QiwiMaps  # NOQA
-from .utils.basics import sync, async_as_sync  # NOQA
-from .utils.exceptions import *  # NOQA
-from .yoo_money import YooMoneyAPI  # NOQA
+from .qiwi import QiwiWrapper, QiwiMaps  # NOQA  # type: ignore
+from .utils.basics import sync, async_as_sync  # NOQA  # type: ignore
+from .utils.exceptions import *  # NOQA  # type: ignore
+from .yoo_money import YooMoneyAPI  # NOQA  # type: ignore
 
-__version__ = '1.0.0'
+__version__ = '1.0.2'
 
 __all__ = (
         (
@@ -14,7 +14,7 @@ __all__ = (
             'QiwiMaps',
             'sync',
             'async_as_sync'
-        ) + utils.exceptions.__all__  # NOQA
+        ) + utils.exceptions.__all__  # NOQA  # type: ignore
 )
 
 
