@@ -1,4 +1,4 @@
-from .API import QiwiWrapper
+from .client import QiwiWrapper
 from .qiwi_maps import QiwiMaps
 
 __all__ = ('QiwiWrapper', 'QiwiMaps')
