@@ -115,7 +115,7 @@ class QiwiSettings:
     # Payload data
     DEFAULT_QIWI_HEADERS: Optional[Dict[str, Union[str, int]]] = None
 
-    ERROR_CODE_NUMBERS: Optional[Dict[str, Union[str, int]]] = None
+    ERROR_CODE_NUMBERS: Optional[Dict[int, str]] = None
 
     P2P_QIWI_HEADERS: Optional[Dict[str, Union[str, int]]] = None
 
@@ -132,21 +132,21 @@ class QiwiSettings:
             'Content-Type': 'application/json',
         }
         self.ERROR_CODE_NUMBERS = {
-            "400": "Недостаточно средств для проведения операции",
-            "401": "Неверный токен или истек срок действия токена API",
-            "403": "Нет прав на данный запрос"
+            400: "Недостаточно средств для проведения операции",
+            401: "Неверный токен или истек срок действия токена API",
+            403: "Нет прав на данный запрос"
                    "(недостаточно разрешений у токена API)",
-            "404": "Не найдена транзакция или "
+            404: "Не найдена транзакция или "
                    "отсутствуют платежи с указанными признаками",
-            "423": "Слишком много запросов, сервис временно недоступен",
-            "422": "Неправильно указаны домен/подсеть/хост"
+            423: "Слишком много запросов, сервис временно недоступен",
+            422: "Неправильно указаны домен/подсеть/хост"
                    " веб-хука(в параметре new_url для URL веб-хука), "
                    "неправильно указаны тип хука или тип транзакции, "
                    "попытка создать хук при наличии уже созданного",
-            "405": "Ошибка, связанная с типом запроса к апи,"
+            405: "Ошибка, связанная с типом запроса к апи,"
                    "обратитесь к разработчику или откройте issue",
-            "500": "Внутренняя ошибка сервиса",
-            "400_special_bad_proxy": "Ошибка, связанная с использованием прокси"
+            500: "Внутренняя ошибка сервиса",
+            0: "Ошибка, связанная с использованием прокси или с проблемами библиотеки"
         }
         self.QIWI_MASTER = {
             "id": str(int(time.time() * 1000)),
