@@ -1,12 +1,12 @@
 from datetime import date
 from typing import Optional
 
-from pydantic import BaseModel, Field
+from pydantic import Field
 
-from glQiwiApi.utils.basics import custom_load
+from glQiwiApi.types.base import Base
 
 
-class Identification(BaseModel):
+class Identification(Base):
     """ object: Identification """
     identification_id: int = Field(..., alias="id")
     first_name: str = Field(..., alias="firstName")
@@ -18,13 +18,3 @@ class Identification(BaseModel):
     snils: Optional[str]
     oms: Optional[str]
     type: str
-
-    class Config:
-        """ Pydantic config """
-        json_loads = custom_load
-
-        def __str__(self) -> str:
-            return f'Config class with loads={self.json_loads}'
-
-        def __repr__(self) -> str:
-            return self.__str__()
