@@ -1,7 +1,9 @@
-from pydantic import BaseModel, Field
+from pydantic import Field
+
+from glQiwiApi.types.base import Base
 
 
-class Restriction(BaseModel):
+class Restriction(Base):
     code: str = Field(..., alias="restrictionCode")
     description: str = Field(..., alias="restrictionDescription")
 
