@@ -1,11 +1,12 @@
 from typing import List
 
-from pydantic import BaseModel, Field
+from pydantic import Field
 
+from glQiwiApi.types.base import Base
 from glQiwiApi.types.basics import Sum
 
 
-class Statistic(BaseModel):
+class Statistic(Base):
     """ object: Statistic """
     incoming: List[Sum] = Field(alias="incomingTotal")
     out: List[Sum] = Field(alias="outgoingTotal")
