@@ -1,13 +1,13 @@
 from datetime import datetime
 from typing import Optional
 
-from pydantic import BaseModel, Field
+from pydantic import Field
 
 from glQiwiApi.types import Sum
-from glQiwiApi.utils.basics import custom_load
+from glQiwiApi.types.base import Base
 
 
-class Payment(BaseModel):
+class Payment(Base):
     """ Scheme of webhook payment object """
     account: str = Field(..., alias="account")
     comment: str = Field(..., alias="comment")
@@ -24,7 +24,7 @@ class Payment(BaseModel):
     total: Sum = Field(..., alias="total")
 
 
-class WebHook(BaseModel):
+class WebHook(Base):
     """
     Хуки или уведомления с данными о событии (платеже/пополнении)
 
@@ -37,17 +37,14 @@ class WebHook(BaseModel):
     version: str = Field(..., alias="version")
     payment: Optional[Payment] = Field(default=None, alias="payment")
 
-    class Config:
-        json_loads = custom_load
 
-
-class HookParameters(BaseModel):
+class HookParameters(Base):
     """hookParameters object"""
 
     url: str = Field(..., alias="url")
 
 
-class WebHookConfig(BaseModel):
+class WebHookConfig(Base):
     """WebHookConfig object"""
 
     hook_id: str = Field(..., alias="hookId")
@@ -55,8 +52,5 @@ class WebHookConfig(BaseModel):
     txn_type: str = Field(..., alias="txnType")
     hook_parameters: HookParameters = Field(..., alias="hookParameters")
 
-    class Config:
-        json_loads = custom_load
-
 
 __all__ = ('WebHookConfig', 'WebHook')
